@@ -1,4 +1,5 @@
 import shutil
+import shlex
 import subprocess
 from pynonymizer.database.exceptions import DependencyError
 """
@@ -6,21 +7,22 @@ Seperate everything that touches actual query exec into its own module
 """
 
 class MySqlDumpRunner:
-    def __init__(self, db_host, db_user, db_pass, db_name, db_port="3306"):
+    def __init__(self, db_host, db_user, db_pass, db_name, db_port="3306", additional_opts = ""):
         self.db_host = db_host
         self.db_user = db_user
         self.db_pass = db_pass
         self.db_name = db_name
         self.db_port = db_port
+        self.additional_opts = shlex.split(additional_opts)
 
         if not (shutil.which("mysqldump")):
             raise DependencyError( "mysqldump", "The 'mysqldump' client must be present in the $PATH")
 
     def __get_base_params(self):
-        return ["mysqldump", "--host", self.db_host, "--port", self.db_port, "--user", self.db_user, f"-p{self.db_pass}"]
+        return self.additional_opts + ["--host", self.db_host, "--port", self.db_port, "--user", self.db_user, f"-p{self.db_pass}"]
 
     def open_dumper(self):
-        return subprocess.Popen(self.__get_base_params() + [self.db_name], stdout=subprocess.PIPE).stdout
+        return subprocess.Popen(["mysqldump"] + self.__get_base_params() + [self.db_name], stdout=subprocess.PIPE).stdout
 
 
 class MySqlCmdRunner:
