@@ -14,9 +14,9 @@ def test_init_runners_correctly(execution):
     """
     Test the provider inits dependencies with the correct database information
     """
-    MySqlProvider("1.2.3.4", "root", "password", "db_name")
+    MySqlProvider("1.2.3.4", "root", "password", "db_name", dump_opts="--test-arg=3")
     execution.MySqlCmdRunner.assert_called_once_with(db_host="1.2.3.4", db_user="root", db_pass="password", db_name="db_name", db_port="3306")
-    execution.MySqlDumpRunner.assert_called_once_with(db_host="1.2.3.4", db_user="root", db_pass="password", db_name="db_name", db_port="3306")
+    execution.MySqlDumpRunner.assert_called_once_with(db_host="1.2.3.4", db_user="root", db_pass="password", db_name="db_name", db_port="3306", additional_opts="--test-arg=3")
 
 
 @patch("pynonymizer.database.mysql.execution", autospec=True)
